@@ -1,7 +1,7 @@
 package Carton;
 use strict;
 use 5.008_005;
-use version; our $VERSION = version->declare("v1.0.34");
+use version; our $VERSION = version->declare("v1.0.35");
 
 1;
 __END__
@@ -172,10 +172,6 @@ with perl lower than the specified version.
 
 Code repository, Wiki and Issue Tracker
 
-=item L<irc://irc.perl.org/#cpanm>
-
-IRC chat room
-
 =back
 
 =head1 AUTHOR
@@ -192,6 +188,8 @@ This software is licensed under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
+L<Carmel>
+
 L<cpanm>
 
 L<cpanfile>
