@@ -1,14 +1,31 @@
 package Carton::CPANfile;
-use Moo;
-use warnings NONFATAL => 'all';
 use Path::Tiny ();
 use Module::CPANfile;
 
 use overload q{""} => sub { $_[0]->stringify }, fallback => 1;
 
-has path => (is => 'rw', coerce => sub { Path::Tiny->new($_[0]) }, handles => [ qw(stringify dirname) ]);
-has _cpanfile => (is => 'rw', handles => [ qw(prereqs) ]);
-has requirements => (is => 'rw', lazy => 1, builder => 1, handles => [ qw(required_modules requirements_for_module) ]);
+use subs 'path';
+
+use Class::Tiny {
+    path => undef,
+    _cpanfile => undef,
+    requirements => sub { $_[0]->_build_requirements },
+};
+
+sub stringify { shift->path->stringify(@_) }
+sub dirname   { shift->path->dirname(@_) }
+sub prereqs   { shift->_cpanfile->prereqs(@_) }
+sub required_modules { shift->requirements->required_modules(@_) }
+sub requirements_for_module { shift->requirements->requirements_for_module(@_) }
+
+sub path {
+    my $self = shift;
+    if (@_) {
+        $self->{path} = Path::Tiny->new($_[0]);
+    } else {
+        $self->{path};
+    }
+}
 
 sub load {
     my $self = shift;
